@@ -1,12 +1,17 @@
+import datetime
 from typing import Dict, List, Tuple, TypeVar, Optional, Collection
 
 import redis
 
 from .. import app_settings
 from ..job import Job
-from .base import BackendWithDeduplicate
+from .base import (
+    BackendWithClear,
+    BackendWithDeduplicate,
+    BackendWithPauseResume,
+)
 from ..types import QueueName, WorkerNumber
-from ..utils import get_worker_numbers
+from ..utils import block_for_time, get_worker_numbers
 from ..progress_logger import ProgressLogger, NULL_PROGRESS_LOGGER
 
 # Work around https://github.com/python/mypy/issues/9914. Name needs to match
@@ -14,7 +19,7 @@ from ..progress_logger import ProgressLogger, NULL_PROGRESS_LOGGER
 T = TypeVar('T')
 
 
-class ReliableRedisBackend(BackendWithDeduplicate):
+class ReliableRedisBackend(BackendWithClear, BackendWithDeduplicate, BackendWithPauseResume):
     """
     This backend manages a per-queue-per-worker 'processing' queue. E.g. if we
     had a queue called 'django_lightweight_queue:things', and two workers, we
@@ -61,16 +66,23 @@ class ReliableRedisBackend(BackendWithDeduplicate):
         )
         processing_queue_keys = current_processing_queue_keys - expected_processing_queue_keys
 
-        def move_processing_jobs_to_main(pipe: redis.client.Pipeline) -> None:
+        def move_processing_jobs_to_main(pipe: 'redis.StrictRedis[bytes]') -> None:
+            # Note: the `pipe` argument here is actually a Pipeline (strictly
+            # `redis.client.Pipeline[bytes]`), however it's not the usual
+            # late-executing pipeline that might be expected (or that the
+            # typeshed expects) so we pretend that it's a StrictRedis instance
+            # to get the type checking to *mostly* work. See typeshed issue
+            # https://github.com/python/typeshed/issues/6028 for more details.
+
             # Collect all the data we need to add, before adding the data back
             # to the main queue of and clearing the processing queues
             # atomically, so if this crashes, we don't lose jobs
-            all_data = []
+            all_data: List[bytes] = []
             for key in processing_queue_keys:
                 all_data.extend(pipe.lrange(key, 0, -1))
 
             if all_data or processing_queue_keys:
-                pipe.multi()
+                pipe.multi()  # type: ignore[attr-defined] # see explanation above
 
             # NB we RPUSH, which means these jobs will get processed next
             if all_data:
@@ -100,6 +112,15 @@ class ReliableRedisBackend(BackendWithDeduplicate):
         main_queue_key = self._key(queue)
         processing_queue_key = self._processing_key(queue, worker_number)
 
+        if self.is_paused(queue):
+            # Block for a while to avoid constant polling ...
+            block_for_time(
+                lambda: self.is_paused(queue),
+                timeout=datetime.timedelta(seconds=timeout),
+            )
+            # ... but always indicate that we did no work
+            return None
+
         # Get any jobs off our 'processing' queue - but do not block doing so -
         # this is to catch the fact there may be a job already in our
         # processing queue if this worker crashed and has just been restarted.
@@ -184,11 +205,44 @@ class ReliableRedisBackend(BackendWithDeduplicate):
 
         return original_size, self.client.llen(main_queue_key)
 
+    def pause(self, queue: QueueName, until: datetime.datetime) -> None:
+        """
+        Pause the given queue by setting a pause marker.
+        """
+
+        pause_key = self._pause_key(queue)
+
+        now = datetime.datetime.now(datetime.timezone.utc)
+        delta = until - now
+
+        self.client.setex(
+            pause_key,
+            time=int(delta.total_seconds()),
+            # Store the value for debugging, we rely on setex behaviour for
+            # implementation.
+            value=until.isoformat(' '),
+        )
+
+    def resume(self, queue: QueueName) -> None:
+        """
+        Resume the given queue by deleting the pause marker (if present).
+        """
+        self.client.delete(self._pause_key(queue))
+
+    def is_paused(self, queue: QueueName) -> bool:
+        return bool(self.client.exists(self._pause_key(queue)))
+
+    def clear(self, queue: QueueName) -> None:
+        self.client.delete(self._key(queue))
+
     def _key(self, queue: QueueName) -> str:
         key = 'django_lightweight_queue:{}'.format(queue)
 
         return self._prefix_key(key)
 
+    def _pause_key(self, queue: QueueName) -> str:
+        return self._key(queue) + ':pause'
+
     def _processing_key(self, queue: QueueName, worker_number: WorkerNumber) -> str:
         key = 'django_lightweight_queue:{}:processing:{}'.format(
             queue,
