@@ -1,26 +1,14 @@
 from typing import Any
 
-from django.core.management.base import BaseCommand, CommandParser
-
 from ... import app_settings
-from ...utils import get_backend, get_queue_counts, load_extra_config
+from ...utils import get_backend, get_queue_counts
+from ...command_utils import CommandWithExtraSettings
 from ...cron_scheduler import get_cron_config
 
 
-class Command(BaseCommand):
-    def add_arguments(self, parser: CommandParser) -> None:
-        parser.add_argument(
-            '--config',
-            action='store',
-            default=None,
-            help="The path to an additional django-style config file to load",
-        )
-
+class Command(CommandWithExtraSettings):
     def handle(self, **options: Any) -> None:
-        # Configuration overrides
-        extra_config = options['config']
-        if extra_config is not None:
-            load_extra_config(extra_config)
+        super().handle_extra_settings(**options)
 
         print("django-lightweight-queue")
         print("========================")
