@@ -3,20 +3,19 @@ from typing import Any, Dict, Optional
 import daemonize
 
 from django.apps import apps
-from django.core.management.base import (
-    BaseCommand,
-    CommandError,
-    CommandParser,
-)
+from django.core.management.base import CommandError, CommandParser
 
 from ...types import QueueName
-from ...utils import get_logger, get_backend, get_middleware, load_extra_config
+from ...utils import get_logger, get_backend, get_middleware
 from ...runner import runner
+from ...command_utils import CommandWithExtraSettings
 from ...machine_types import Machine, PooledMachine, DirectlyConfiguredMachine
 
 
-class Command(BaseCommand):
+class Command(CommandWithExtraSettings):
     def add_arguments(self, parser: CommandParser) -> None:
+        super().add_arguments(parser)
+
         parser.add_argument(
             '--pidfile',
             action='store',
@@ -51,25 +50,20 @@ class Command(BaseCommand):
             default=None,
             help="Only run the given queue, useful for local debugging",
         )
-        parser.add_argument(
-            '--config',
-            action='store',
-            default=None,
-            help="The path to an additional django-style config file to load",
-        )
         parser.add_argument(
             '--exact-configuration',
             action='store_true',
             help="Run queues on this machine exactly as specified. Requires the"
-                 " use of the '--config' option in addition. It is an error to"
-                 " use this option together with either '--machine' or '--of'.",
+                 " use of the '--extra-settings' option in addition. It is an"
+                 " error to use this option together with either '--machine' or"
+                 " '--of'.",
         )
 
-    def validate_and_normalise(self, options: Dict[str, Any]) -> None:
+    def validate_and_normalise(self, options: Dict[str, Any], had_extra_settings: bool) -> None:
         if options['exact_configuration']:
-            if not options['config']:
+            if not had_extra_settings:
                 raise CommandError(
-                    "Must provide a value for '--config' when using "
+                    "Must provide a value for '--extra-settings' when using "
                     "'--exact-configuration'.",
                 )
 
@@ -101,7 +95,12 @@ class Command(BaseCommand):
     def handle(self, **options: Any) -> None:
         logger = get_logger('dlq.master')
 
-        self.validate_and_normalise(options)
+        extra_settings = super().handle_extra_settings(**options)
+
+        self.validate_and_normalise(
+            options,
+            had_extra_settings=extra_settings is not None,
+        )
 
         def touch_filename(name: str) -> Optional[str]:
             try:
@@ -109,11 +108,6 @@ class Command(BaseCommand):
             except TypeError:
                 return None
 
-        # Configuration overrides
-        extra_config = options['config']
-        if extra_config is not None:
-            load_extra_config(extra_config)
-
         logger.info("Starting queue master")
 
         # Ensure children will be able to import our backend
@@ -138,7 +132,7 @@ class Command(BaseCommand):
             )
 
         def run() -> None:
-            runner(touch_filename, machine, logger)
+            runner(touch_filename, machine, logger, extra_settings)
 
         # fork() only after we have started enough to catch failure, including
         # being able to write to our pidfile.
